@@ -47,7 +47,10 @@ sub run {
                     %setup = @_;
                 },
                 handler    => sub {
-                    my $base = "http://$setup{localname}:$setup{localport}";
+                    my($host, $port) = $headers->header('Host') ?
+                        split(':', $headers->header('Host')) :($setup{localname}, $setup{localport});
+                    my $base = "http://${host}";
+                    $base .= ":$port" if $port;
                     my $request_uri = $setup{request_uri};
                     $request_uri = '/' if $request_uri =~ m!^https?://!i;
                     my $uri = URI::WithBase->new(
