@@ -1,5 +1,3 @@
-#!/usr/bin/perl
-
 package HTTP::Engine::Role::Request;
 use Moose::Role;
 
@@ -31,22 +29,4 @@ requires qw(
     content
 );
 
-__PACKAGE__
-
-__END__
-
-=pod
-
-=head1 NAME
-
-HTTP::Engine::Role::Request - 
-
-=head1 SYNOPSIS
-
-	use HTTP::Engine::Role::Request;
-
-=head1 DESCRIPTION
-
-=cut
-
-
+1;
